@@ -21,22 +21,29 @@
  */
 
 #include "result.h"
-#include "../util.h"
 
-#include <KDebug>
-#include <qjson/serializer.h>
+#include <QDebug>
+#include <QJsonDocument>
+#include <QJsonObject>
 
 #include <QDateTime>
-#include <kfilemetadata/propertyinfo.h>
-#include <kfilemetadata/typeinfo.h>
+#include <KFileMetaData/PropertyInfo>
+#include <KFileMetaData/TypeInfo>
 
 // In order to use it in a vector
-Result::Result(): ExtractionResult(QString(), QString()), m_docId(0), m_readOnly(false)
+Result::Result()
+    : ExtractionResult(QString(), QString())
+    , m_docId(0)
+    , m_termGen(0)
+    , m_termGenForText(0)
 {
 }
 
-Result::Result(const QString& url, const QString& mimetype)
-    : KFileMetaData::ExtractionResult(url, mimetype), m_docId(0), m_readOnly(false)
+Result::Result(const QString& url, const QString& mimetype, const Flags& flags)
+    : KFileMetaData::ExtractionResult(url, mimetype, flags)
+    , m_docId(0)
+    , m_termGen(0)
+    , m_termGenForText(0)
 {
 }
 
@@ -54,27 +61,29 @@ void Result::add(KFileMetaData::Property::Property property, const QVariant& val
         const QString term = prefix + value.toString();
         m_doc.add_term(term.toUtf8().constData());
     }
+    else if (value.type() == QVariant::Date) {
+        const QString term = prefix + value.toDate().toString(Qt::ISODate);
+        m_doc.add_term(term.toUtf8().constData());
+    }
     else if (value.type() == QVariant::DateTime) {
         const QString term = prefix + value.toDateTime().toString(Qt::ISODate);
         m_doc.add_term(term.toUtf8().constData());
     }
     else {
-        const QByteArray val = value.toString().toUtf8();
+        const QString val = value.toString();
         if (val.isEmpty())
             return;
 
-        m_termGen.index_text(val.constData(), 1, prefix.toUtf8().constData());
+        m_termGen.indexText(val, prefix);
         KFileMetaData::PropertyInfo pi(property);
         if (pi.shouldBeIndexed())
-            m_termGen.index_text(val.constData());
+            m_termGen.indexText(val);
     }
 }
 
 void Result::append(const QString& text)
 {
-    if (!m_readOnly) {
-        m_termGenForText.index_text(text.toUtf8().constData());
-    }
+    m_termGenForText.indexText(text);
 }
 
 void Result::addType(KFileMetaData::Type::Type type)
@@ -84,30 +93,25 @@ void Result::addType(KFileMetaData::Type::Type type)
     m_doc.add_boolean_term(t.toUtf8().constData());
 }
 
-void Result::setReadOnly(bool readOnly)
-{
-    m_readOnly = readOnly;
-}
-
 void Result::finish()
 {
-    QJson::Serializer serializer;
-    QByteArray json = serializer.serialize(m_map);
-    m_doc.set_data(json.constData());
-    Baloo::updateIndexingLevel(m_doc, 2);
+    QJsonObject jo = QJsonObject::fromVariantMap(m_map);
+    QJsonDocument jdoc;
+    jdoc.setObject(jo);
+    m_doc.set_data(jdoc.toJson().constData());
 }
 
 void Result::setDocument(const Xapian::Document& doc)
 {
     m_doc = doc;
     // All document metadata are indexed from position 1000
-    m_termGen.set_document(m_doc);
-    m_termGen.set_termpos(1000);
+    m_termGen.setDocument(&m_doc);
+    m_termGen.setPosition(1000);
 
     // All document plain text starts from 10000. This is done to avoid
     // clashes with the term positions
-    m_termGenForText.set_document(m_doc);
-    m_termGenForText.set_termpos(10000);
+    m_termGenForText.setDocument(&m_doc);
+    m_termGenForText.setPosition(10000);
 }
 
 void Result::setId(uint id)
