@@ -1,5 +1,6 @@
-/* This file is part of the KDE Project
+/*
    Copyright (c) 2008-2009 Sebastian Trueg <trueg@kde.org>
+   Copyright (c) 2012-2014 Vishesh Handa <me@vhanda.in>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -16,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef _NEPOMUK_FILEINDEXER_SERVICE_CONFIG_H_
-#define _NEPOMUK_FILEINDEXER_SERVICE_CONFIG_H_
+#ifndef _BALOO_FILEINDEXER_SERVICE_CONFIG_H_
+#define _BALOO_FILEINDEXER_SERVICE_CONFIG_H_
 
 #include <QtCore/QObject>
 #include <QtCore/QList>
@@ -29,6 +30,9 @@
 
 namespace Baloo
 {
+
+class StorageDevices;
+
 /**
  * Active config class which emits signals if the config
  * was changed, for example if the KCM saved the config file.
@@ -44,13 +48,6 @@ public:
     FileIndexerConfig(QObject* parent = 0);
     ~FileIndexerConfig();
 
-    /**
-     * A cleaned up list of all include and exclude folders
-     * with their respective include/exclude flag sorted by
-     * path. None of the paths have trailing slashes.
-     */
-    QList<QPair<QString, bool> > folders() const;
-
     /**
      * The folders to search for files to analyze. Cached and cleaned up.
      */
@@ -66,6 +63,8 @@ public:
 
     bool indexHiddenFilesAndFolders() const;
 
+    bool onlyBasicIndexing() const;
+
     /**
      * true the first time the service is run (or after manually
      * tampering with the config.
@@ -177,7 +176,11 @@ private:
     QSet<QString> m_excludeMimetypes;
 
     bool m_indexHidden;
+    bool m_onlyBasicIndexing;
+
+    StorageDevices* m_devices;
 };
+
 }
 
 #endif
