@@ -1,6 +1,6 @@
 /*
    Copyright (C) 2008-2010 by Sebastian Trueg <trueg at kde.org>
-   Copyright (C) 2012-2013 by Vishesh Handa <me@vhanda.in>
+   Copyright (C) 2012-2014 by Vishesh Handa <me@vhanda.in>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,12 +21,13 @@
 
 #include "query.h"
 #include "resultiterator.h"
+#include "advancedqueryparser.h"
 
 #include <QUrl>
+#include <QUrlQuery>
 #include <KUser>
 #include <QDebug>
 #include <QCoreApplication>
-#include <KSharedConfig>
 #include <KLocalizedString>
 
 #include <KIO/Job>
@@ -43,12 +44,13 @@ KIO::UDSEntry statSearchFolder(const QUrl& url)
     uds.insert(KIO::UDSEntry::UDS_USER, KUser().loginName());
     uds.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
     uds.insert(KIO::UDSEntry::UDS_MIME_TYPE, QString::fromLatin1("inode/directory"));
-    uds.insert(KIO::UDSEntry::UDS_ICON_OVERLAY_NAMES, QLatin1String("nepomuk"));
-    uds.insert(KIO::UDSEntry::UDS_DISPLAY_TYPE, i18n("Query folder"));
+    uds.insert(KIO::UDSEntry::UDS_ICON_OVERLAY_NAMES, QLatin1String("baloo"));
+    uds.insert(KIO::UDSEntry::UDS_DISPLAY_TYPE, i18n("Search Folder"));
     uds.insert(KIO::UDSEntry::UDS_URL, url.url());
 
-    QString title = url.queryItemValue(QLatin1String("title"));
-    if (title.size()) {
+    QUrlQuery query(url);
+    QString title = query.queryItemValue(QLatin1String("title"), QUrl::FullyDecoded);
+    if (!title.isEmpty()) {
         uds.insert(KIO::UDSEntry::UDS_NAME, title);
         uds.insert(KIO::UDSEntry::UDS_DISPLAY_NAME, title);
     }
@@ -56,13 +58,6 @@ KIO::UDSEntry statSearchFolder(const QUrl& url)
     return uds;
 }
 
-bool isRootUrl(const QUrl& url)
-{
-    const QString path = url.path();
-    return (!url.hasQuery() &&
-            (path.isEmpty() || path == QLatin1String("/")));
-}
-
 }
 
 SearchProtocol::SearchProtocol(const QByteArray& poolSocket, const QByteArray& appSocket)
@@ -77,12 +72,21 @@ SearchProtocol::~SearchProtocol()
 
 void SearchProtocol::listDir(const QUrl& url)
 {
-    // list the root folder
-    if (isRootUrl(url)) {
-        finished();
+    Query q;
+
+    QUrlQuery urlQuery(url);
+    if (urlQuery.hasQueryItem("json")) {
+        QString jsonString = urlQuery.queryItemValue(QStringLiteral("json"), QUrl::FullyDecoded);
+        q = Query::fromJSON(jsonString.toUtf8());
+    } else if (urlQuery.hasQueryItem("query")) {
+        QString queryString = urlQuery.queryItemValue(QStringLiteral("query"), QUrl::FullyDecoded);
+
+        AdvancedQueryParser aqp;
+        q.setTerm(aqp.parse(queryString));
+        q.setType("File");
     }
 
-    Query q = Query::fromSearchUrl(url);
+    q.setSortingOption(Query::SortNone);
     ResultIterator it = q.exec();
 
     while (it.next()) {
@@ -141,30 +145,8 @@ void SearchProtocol::mimetype(const QUrl&)
 
 void SearchProtocol::stat(const QUrl& url)
 {
-    // the root folder
-    if (isRootUrl(url)) {
-        //
-        // stat the root path
-        //
-        KIO::UDSEntry uds;
-        uds.insert(KIO::UDSEntry::UDS_NAME, QString::fromLatin1("/"));
-        uds.insert(KIO::UDSEntry::UDS_DISPLAY_NAME, i18n("Desktop Queries"));
-        uds.insert(KIO::UDSEntry::UDS_ICON_NAME, QString::fromLatin1("nepomuk"));
-        uds.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
-        uds.insert(KIO::UDSEntry::UDS_MIME_TYPE, QString::fromLatin1("inode/directory"));
-
-        statEntry(uds);
-        finished();
-    }
-
-    // qDebug() << "Stat search folder" << url;
     statEntry(statSearchFolder(url));
     finished();
-
-    /*else {
-        error(KIO::ERR_CANNOT_ENTER_DIRECTORY, url.toString());
-        return;
-    }*/
 }
 
 extern "C"
