@@ -31,7 +31,9 @@ class ContactSearchStore : public PIMSearchStore
 {
     Q_OBJECT
     Q_INTERFACES(Baloo::SearchStore)
-    Q_PLUGIN_METADATA(IID "org.kde.baloo.contacts" FILE "baloocontactsearchstore.json")
+#ifndef BALOO_NO_PLUGINS
+    Q_PLUGIN_METADATA(IID "org.kde.Baloo.SearchStore")
+#endif
 public:
     ContactSearchStore(QObject* parent = 0);
 
