@@ -31,7 +31,9 @@ class EmailSearchStore : public PIMSearchStore
 {
     Q_OBJECT
     Q_INTERFACES(Baloo::SearchStore)
-    Q_PLUGIN_METADATA(IID "org.kde.baloo.email" FILE "balooemailsearchstore.json")
+#ifndef BALOO_NO_PLUGINS
+    Q_PLUGIN_METADATA(IID "org.kde.Baloo.SearchStore")
+#endif
 public:
     EmailSearchStore(QObject* parent = 0);
 
