@@ -56,7 +56,7 @@ int main(int argc, char* argv[])
 {
     KAboutData aboutData(QLatin1String("baloosearch"),
                          i18n("Baloo Search"),
-                         QLatin1String("0.1"),
+                         PROJECT_VERSION,
                          i18n("Baloo Search - A debugging tool"),
                          KAboutLicense::GPL,
                          i18n("(c) 2013, Vishesh Handa"));
