@@ -19,10 +19,12 @@
  */
 
 #include "termgeneratortest.h"
-#include "../termgenerator.h"
+#include "../xapiantermgenerator.h"
+#include "../xapiandatabase.h"
 
 #include <QTest>
 #include <QDebug>
+#include <QTemporaryDir>
 
 using namespace Baloo;
 
@@ -43,7 +45,7 @@ void TermGeneratorTest::testWordBoundaries()
     QString str = QString::fromLatin1("The quick (\"brown\") 'fox' can't jump 32.3 feet, right? No-Wrong;xx.txt");
 
     Xapian::Document doc;
-    TermGenerator termGen(&doc);
+    XapianTermGenerator termGen(&doc);
     termGen.indexText(str);
 
     QStringList words = allWords(doc);
@@ -61,7 +63,7 @@ void TermGeneratorTest::testUnderscore_splitting()
     QString str = QString::fromLatin1("Hello_Howdy");
 
     Xapian::Document doc;
-    TermGenerator termGen(&doc);
+    XapianTermGenerator termGen(&doc);
     termGen.indexText(str);
 
     QStringList words = allWords(doc);
@@ -69,7 +71,6 @@ void TermGeneratorTest::testUnderscore_splitting()
     QStringList expectedWords;
     expectedWords << QLatin1String("hello") << QLatin1String("howdy");
 
-    QEXPECT_FAIL("", "Xapian does not split on _", Continue);
     QCOMPARE(words, expectedWords);
 }
 
@@ -78,17 +79,88 @@ void TermGeneratorTest::testAccetCharacters()
     QString str = QString::fromLatin1("Como est Kg");
 
     Xapian::Document doc;
-    TermGenerator termGen(&doc);
+    XapianTermGenerator termGen(&doc);
     termGen.indexText(str);
 
     QStringList words = allWords(doc);
 
     QStringList expectedWords;
-    expectedWords << QLatin1String("esta") << QLatin1String("como") << QLatin1String("kug");
+    expectedWords << QLatin1String("como") << QLatin1String("esta") << QLatin1String("kug");
 
-    QEXPECT_FAIL("", "Xapian does not handle diarectics", Continue);
     QCOMPARE(words, expectedWords);
 }
 
+void TermGeneratorTest::testUnicodeCompatibleComposition()
+{
+    // The 0xfb00 corresponds to U+FB00 which is a 'ff'
+    QString str = QLatin1Literal("maffab");
+    QString str2 = QLatin1Literal("ma") + QChar(0xfb00) + QStringLiteral("ab");
+
+    Xapian::Document doc;
+    XapianTermGenerator termGen(&doc);
+    termGen.indexText(str2);
+
+    QStringList words = allWords(doc);
+    QCOMPARE(words.size(), 1);
+
+    QString output = words.first();
+    QCOMPARE(str, output);
+}
+
+void TermGeneratorTest::testEmails()
+{
+    QString str = QString::fromLatin1("me@vhanda.in");
+
+    Xapian::Document doc;
+    XapianTermGenerator termGen(&doc);
+    termGen.indexText(str);
+
+    QStringList words = allWords(doc);
+
+    QStringList expectedWords;
+    expectedWords << QLatin1String("in") << QLatin1String("me") << QLatin1String("vhanda");
+
+    QCOMPARE(words, expectedWords);
+}
+
+void TermGeneratorTest::testWordPositions()
+{
+    QTemporaryDir dir;
+    XapianDatabase db(dir.path(), true);
+
+    Xapian::Document doc;
+    XapianTermGenerator termGen(&doc);
+
+    QString str = QString::fromLatin1("Hello hi how hi");
+    termGen.indexText(str);
+
+    db.replaceDocument(1, doc);
+
+    Xapian::Database* xap = db.db();
+
+    Xapian::PositionIterator it = xap->positionlist_begin(1, "hello");
+    Xapian::PositionIterator end = xap->positionlist_end(1, "hello");
+    QVERIFY(it != end);
+    QCOMPARE(*it, (uint)1);
+    it++;
+    QVERIFY(it == end);
+
+    it = xap->positionlist_begin(1, "hi");
+    end = xap->positionlist_end(1, "hi");
+    QVERIFY(it != end);
+    QCOMPARE(*it, (uint)2);
+    it++;
+    QCOMPARE(*it, (uint)4);
+    it++;
+    QVERIFY(it == end);
+
+    it = xap->positionlist_begin(1, "how");
+    end = xap->positionlist_end(1, "how");
+    QVERIFY(it != end);
+    QCOMPARE(*it, (uint)3);
+    it++;
+    QVERIFY(it == end);
+}
+
 QTEST_MAIN(TermGeneratorTest)
 
